get_external_ptr_addr: Get the address of an external pointer

View source: R/tinycc.R

get_external_ptr_addrR Documentation

Get the address of an external pointer

Description

Extract the memory address from an external pointer as a numeric value. This is primarily useful for debugging and inspection purposes.

Usage

get_external_ptr_addr(ptr)

Arguments

ptr

An external pointer object (e.g., from tcc_get_symbol()).

Value

The memory address as a numeric value.


Rtinycc documentation built on April 28, 2026, 1:07 a.m.