Skip to contents

Print tcc_compiled object

Usage

# S3 method for class 'tcc_compiled'
print(x, ...)

Arguments

x

A tcc_compiled object

...

Ignored

Value

The input tcc_compiled object, invisibly. Called for its side effect of printing the compilation output mode and the status of compiled callable symbols.