| tcc_introspect | R Documentation |
Generates sizeof, alignof, and offsetof helper functions for structs, unions, and enums. Useful for debugging or when you need to know C layout information from R.
tcc_introspect(ffi)
ffi |
A tcc_ffi object |
Updated tcc_ffi object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.