tcc_malloc: Allocate memory buffer

View source: R/tcc_ptr_utils.R

tcc_mallocR Documentation

Allocate memory buffer

Description

Allocate a memory buffer of specified size, equivalent to C malloc. Returns an external pointer that can be passed to FFI functions.

Usage

tcc_malloc(size)

Arguments

size

Number of bytes to allocate

Value

An external pointer tagged "rtinycc_owned" with an R finalizer. Freed on garbage collection or explicitly via tcc_free().


Rtinycc documentation built on April 28, 2026, 1:07 a.m.