tcc_ptr_free_set_null: Free the pointed memory and set to NULL

View source: R/tcc_ptr_utils.R

tcc_ptr_free_set_nullR Documentation

Free the pointed memory and set to NULL

Description

Frees the memory pointed to by ptr_ref and sets the pointer to NULL. Use this only when the pointed memory is not already owned by another external pointer with its own finalizer.

Usage

tcc_ptr_free_set_null(ptr_ref)

Arguments

ptr_ref

External pointer to a pointer value.

Value

The updated pointer reference (invisibly).


Rtinycc documentation built on April 28, 2026, 1:07 a.m.