Relocation is valid only for a state created with output = "memory" and
can be performed only once. Callable symbols are unavailable until relocation
succeeds. Use tcc_output_file() for object, shared-library, executable, or
preprocessor output.
Relocation is valid only for a state created with output = "memory" and
can be performed only once. Callable symbols are unavailable until relocation
succeeds. Use tcc_output_file() for object, shared-library, executable, or
preprocessor output.