Initialize a libtcc compilation state, optionally pointing at the bundled
include/lib paths. Memory states are finalized with tcc_relocate(); other
output modes are written with tcc_output_file(). Finalization is
single-shot, after which compilation options and source cannot be changed.
Usage
tcc_state(
output = c("memory", "obj", "dll", "exe", "preprocess"),
include_path = tcc_include_paths(),
lib_path = tcc_lib_paths()
)