| get_external_ptr_addr | R Documentation |
Extract the memory address from an external pointer as a numeric value. This is primarily useful for debugging and inspection purposes.
get_external_ptr_addr(ptr)
ptr |
An external pointer object (e.g., from |
The memory address as a numeric value.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.