print.tcc_compiled: Print tcc_compiled object

print.tcc_compiledR Documentation

Print tcc_compiled object

Description

Print tcc_compiled object

Usage

## S3 method for class 'tcc_compiled'
print(x, ...)

Arguments

x

A tcc_compiled object

...

Ignored

Value

The input tcc_compiled object, invisibly. Called for its side effect of printing the compilation output mode and the status of compiled callable symbols.


Rtinycc documentation built on April 28, 2026, 1:07 a.m.