R/ffi.R
print.tcc_compiled.Rd
Print tcc_compiled object
# S3 method for class 'tcc_compiled' print(x, ...)
A tcc_compiled object
Ignored
The input tcc_compiled object, invisibly. Called for its side effect of printing the compilation output mode and the status of compiled callable symbols.
tcc_compiled