tcc_callback_async_schedule: Schedule a callback to run on the main thread

View source: R/callbacks.R

tcc_callback_async_scheduleR Documentation

Schedule a callback to run on the main thread

Description

Enqueue a callback for main-thread execution. Arguments must be basic scalars or external pointers. The callback must remain open until the task executes. External-pointer arguments are borrowed addresses: their owners and pointees must remain valid until execution finishes.

Usage

tcc_callback_async_schedule(callback, args = list())

Arguments

callback

A tcc_callback object

args

List of arguments to pass to the callback

Value

NULL (invisible)


Rtinycc documentation built on July 26, 2026, 1:06 a.m.