| tcc_callback_close | R Documentation |
Invalidates a callback immediately, releases the preserved R function reference, and cleans up callback resources as early as possible. This is recommended for deterministic lifetime management, but callbacks are also eventually released by finalizers if you simply drop all references.
tcc_callback_close(callback)
callback |
A tcc_callback object returned by tcc_callback() |
NULL (invisible)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.