| tcc_get_symbol | R Documentation |
The memory state must first be successfully finalized with tcc_relocate().
tcc_get_symbol(state, name)
state |
A |
name |
Symbol name to look up. |
External pointer of class tcc_symbol. The pointer retains state
so its relocated code remains alive for as long as the symbol is reachable.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.