The memory state must first be successfully finalized with tcc_relocate().
Usage
tcc_get_symbol(state, name)
Arguments
- state
A tcc_state.
- name
Symbol name to look up.
Value
External pointer of class tcc_symbol. The pointer retains state
so its relocated code remains alive for as long as the symbol is reachable.