Add library to link against
Arguments
- ffi
A tcc_ffi object
- library
Library name (e.g., "m", "sqlite3") or a path to a shared library (e.g., "libm.so.6"). When a path or platform library file name is provided, the library directory is added automatically and TinyCC is asked to link that exact file name. This keeps versioned runtime libraries such as
libm.so.6distinct from generic linker names such asm/libm.so.