View source: R/tcc_ptr_utils.R
| tcc_malloc | R Documentation |
Allocate a memory buffer of specified size, equivalent to C malloc. Returns an external pointer that can be passed to FFI functions.
tcc_malloc(size)
size |
Number of bytes to allocate |
An external pointer tagged "rtinycc_owned" with an R finalizer.
Freed on garbage collection or explicitly via tcc_free().
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.